import type { GenericSearchProvider, SearchFilters, SearchMatch } from '@difizen/libro-search';
import { GenericSearchProviderFactory } from '@difizen/libro-search';
import { CodemirrorCellSearchProvider } from './codemirror-cell-search-provider.js';
import { CodeMirrorCodeCellSearchOption, CodeMirrorSearchHighlighterFactory } from './codemirror-search-protocol.js';
export declare class CodeMirrorCodeCellSearchProvider extends CodemirrorCellSearchProvider {
    protected genericSearchProviderFactory: GenericSearchProviderFactory;
    protected outputsProvider: GenericSearchProvider[];
    protected currentProviderIndex: number;
    /**
     * Constructor
     *
     * @param cell Cell widget
     */
    constructor(genericSearchProviderFactory: GenericSearchProviderFactory, highlighterFactory: CodeMirrorSearchHighlighterFactory, option: CodeMirrorCodeCellSearchOption);
    /**
     * Number of matches in the cell.
     */
    get matchesCount(): number;
    /**
     * Clear currently highlighted match.
     */
    clearHighlight(): Promise<void>;
    /**
     * Dispose the search provider
     */
    dispose(): void;
    /**
     * Highlight the next match.
     *
     * @returns The next match if there is one.
     */
    highlightNext(): Promise<SearchMatch | undefined>;
    /**
     * Highlight the previous match.
     *
     * @returns The previous match if there is one.
     */
    highlightPrevious(): Promise<SearchMatch | undefined>;
    /**
     * Initialize the search using the provided options. Should update the UI to highlight
     * all matches and "select" the first match.
     *
     * @param query A RegExp to be use to perform the search
     * @param filters Filter parameters to pass to provider
     */
    startQuery(query: RegExp | null, filters?: SearchFilters): Promise<void>;
    endQuery(): Promise<void>;
    refresh(): Promise<void>;
    protected setupOutputProvider: () => Promise<void>;
}
//# sourceMappingURL=codemirror-code-cell-search-provider.d.ts.map