import type { StateEffectType } from '@codemirror/state';
import { StateField } from '@codemirror/state';
import type { DecorationSet } from '@codemirror/view';
import { Decoration } from '@codemirror/view';
import type { CodeMirrorEditor } from '@difizen/libro-codemirror';
import type { SearchMatch } from '@difizen/libro-search';
import { LibroSearchUtils } from '@difizen/libro-search';
/**
 * Helper class to highlight texts in a code mirror editor.
 *
 * Highlighted texts (aka `matches`) must be provided through
 * the `matches` attributes.
 */
export declare class CodeMirrorSearchHighlighter {
    utils: LibroSearchUtils;
    protected cm: CodeMirrorEditor | undefined;
    _currentIndex: number | undefined;
    protected _matches: SearchMatch[];
    protected highlightEffect: StateEffectType<{
        matches: SearchMatch[];
        currentIndex: number | undefined;
    }>;
    protected highlightMark: Decoration;
    protected selectedMatchMark: Decoration;
    protected highlightField: StateField<DecorationSet>;
    /**
     * The list of matches
     */
    get matches(): SearchMatch[];
    set matches(v: SearchMatch[]);
    get currentIndex(): number | undefined;
    set currentIndex(v: number | undefined);
    /**
     * Constructor
     *
     * @param editor The CodeMirror editor
     */
    constructor(utils: LibroSearchUtils);
    /**
     * Clear all highlighted matches
     */
    clearHighlight(): void;
    /**
     * Clear the highlighted matches.
     */
    endQuery(): Promise<void>;
    /**
     * Highlight the next match
     *
     * @returns The next match if available
     */
    highlightNext(): Promise<SearchMatch | undefined>;
    /**
     * Highlight the previous match
     *
     * @returns The previous match if available
     */
    highlightPrevious(): Promise<SearchMatch | undefined>;
    /**
     * Set the editor
     *
     * @param editor Editor
     */
    setEditor(editor: CodeMirrorEditor): void;
    protected _highlightCurrentMatch(): void;
    protected refresh(): void;
    protected _findNext(reverse: boolean): number | undefined;
}
//# sourceMappingURL=codemirror-search-highlighter.d.ts.map